# Vendored `robustness` package

This directory contains vendored code from the `robustness` repository, developed by the Madry Lab.

- Source: https://github.com/MadryLab/robustness
- Upstream license: MIT
- Vendored code reflects commit with SHA-256: a9541241defd9972e9334bfcdb804f6aefe24dc7
